1.1.1
---
* Remove unused keyring import to prevent keyring dependency issues. 

1.1.0
---
* Update keyring import to be compatible with keyring 23.9.0. 

1.0.0
---
* Upgrading tool to version 1.0.0 since Artifact Registry Python Repositories is now in GA. 

0.0.3
---

* Allow project to bootstrap itself with tox
  https://github.com/GoogleCloudPlatform/artifact-registry-python-tools/issues/7
* Update classname and python endpoints

0.0.2
---

* Fixed None reference when parsing a service which is not a proper URL
  https://github.com/GoogleCloudPlatform/artifact-registry-python-tools/issues/4
